/** \file
 * This header defines the types used in ATL.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Cong Loc Kieu, Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef AtlTypes_h
#define AtlTypes_h


#include <string>

#if !defined(AVATL_MAC) && !defined(AVATL_WIN) && !defined(AVATL_UNIX)
	#if defined(__GNUC__)
		#if defined(__APPLE_CPP__) || defined(__APPLE_CC__)
			#define	AVATL_MAC		1
			#define	AVATL_MACHO		1
		#elif defined(__MACOS_CLASSIC__)
			#define	AVATL_MAC		1
			#define	AVATL_CFM		1
		#else
			#define	AVATL_UNIX		1
		#endif
	#elif defined(__MWERKS__)
		#if defined(__MACH__)
			#define	AVATL_MAC		1
			#define	AVATL_MACHO		1
		#elif defined(macintosh) && macintosh
			#define	AVATL_MAC		1
			#define	AVATL_CFM		1
		#elif defined(__INTEL__)
			#define	AVATL_WIN		1
                #else
                    #error Please specify platform
		#endif
	#elif defined(WIN32) || defined(_WIN32)
		#define	AVATL_WIN			1
	#else
		#error Please specify platform
	#endif
#endif

// If we are building the dynamic library, we have to export some functions.
#ifdef BUILD_ATL
	#ifdef __MWERKS__
 	   #define AVATL_EXP	__declspec(export)
	#else
 	   #define AVATL_EXP	__declspec(dllexport)
	#endif
#else
   #define AVATL_EXP
#endif

#if defined(AVATL_WIN)
   #define AVATL_CALL_CONVENTION __cdecl
#else
   #define AVATL_CALL_CONVENTION
#endif


#define AVATL_STD_XYZ	1


/// Forward declaration for class AbventXML::XIXMLElement
namespace AbventXML
{
	class XIXMLElement;
	class XCXMLTree;
}

/// namespace and typedef for the Abvent ATL library
/** \namespace AvAtl
 * We use this namespace for all members of the ATL library.
 * \author Abvent R&D Copyright (c) 2002
 */
namespace  AvAtl {

// We make our enums int, so you don't have to change your project settings.
#ifdef __MWERKS__
#pragma enumsalwaysint on
#endif


/// Name to specify a unicode character.
/** ATL uses unicode characters (utf8) for all texts. */
typedef char				tUtf8Char;
/// Name to specify a unicode string (as array of chars).
typedef const tUtf8Char*	tUtf8;
/// Name to specify a unicode string (as std::string)
typedef std::string			tUtf8String;

/// Name to specify system encoding (for use with  CAtlUtf8Transcoder.h)
#if defined(AVATL_MAC)
	typedef unsigned long	tOSCode;			// TextEncodingBase on Macintosh
#else
	typedef unsigned int	tOSCode;			// Code page on windows
#endif

/// Name to specify a URL character
/** ATL uses URLs for all references to documents. */
typedef char				tURLChar;
/// Name to specify a URL string (as array of chars).
typedef const tURLChar*		tURL;
/// Name to specify a URL string (as std::string)
typedef std::string			tURLString;

/// Name to specify a Universal Unique IDentifier
typedef const class CAtlUUID&	tUUID;

/// Forward declaration for localizable string
class IAtlString;

/// Name for XMLElementNode pointer.
/** Usage of this type is exclusive to Abvent. */
typedef AbventXML::XIXMLElement*			XMLNodeRef;

/// Name for pointer to const XMLElementNode.
/** Usage of this type is exclusive to Abvent. */
typedef const AbventXML::XIXMLElement*		ConstXMLNodeRef;

/// Name for XCXMLTree pointer.
/** Usage of this type is exclusive to Abvent. */
typedef AbventXML::XCXMLTree*				XMLTreeRef;

/// Version of ATL header used for compilation.
/** This value is automatically passed as needed. */
enum EVersionATL			{ kATL_Version = 20 };

/// Version of extended ATL header used for compilation.
/** For Abvent usage only.
 * This value is automatically passed as needed. */
enum EExtendedVersionATL	{ kATLEx_Version = 5 };


#ifdef __MWERKS__
#pragma enumsalwaysint reset
#endif

} // namespace  AvAtl

#endif
