/** \file
 * Header for the CAtlAmbient interface
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Cong Loc Kieu, Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef CAtlAmbient_h
#define CAtlAmbient_h


// Basic class.
#ifndef CAtlColor_h
	#include "CAtlColor.h"
#endif
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif

// We use this namespace for our library.
namespace  AvAtl {


/// Allow color to be added or subtracted 
/** \interface CAtlAmbient 
 *	Ambient color defines a color intensity that is added to or subtracted from the image.
 * Also note that this color can be negative (-63..63).
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Cong Loc Kieu, Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
class CAtlAmbient
{
public:
	/// Ambient color is signed (-63 to 63).
	typedef TAtlColor<char>			CAmbientColor;

	/// Get the color to be added to the image.
	virtual const CAmbientColor&	getColor() const = 0;
	/// Set the color to be added to the image.
	virtual void					setColor(const CAmbientColor& inColor) = 0;

// End of API 1

	/// Put an XML representation of the ambient inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the ambient with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Control if the ambient is used.
	virtual bool					getFlag() const = 0;
	/// Control if the ambient is used.
	virtual void					setFlag(bool inActive) = 0;

	/// Control if we must use the default ambient.
	virtual bool					getUseDefault() const = 0;
	/// Control if we must use the default ambient.
	virtual void					setUseDefault(bool inUse) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~CAtlAmbient() {}
};


} // namespace  AvAtl

#endif
