/** \file
 * Header for the TAtlColor template
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Cong Loc Kieu, Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef CAtlColor_h
#define CAtlColor_h


// We use this namespace for our library.
namespace  AvAtl {

/// Template for color representation.
/** \class TAtlColor 
 *	Alpha component is currently unused in ATL.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Cong Loc Kieu, Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
template<class componentType>
class TAtlColor
{
public:
	/// Type for component value.
	typedef componentType	tComp;

	/// Constructor.
					TAtlColor()
					:	mA(0), mR(0), mG(0), mB(0)
					{}
	/// Constructor.
					TAtlColor(tComp r, tComp g, tComp b, tComp a = 0)
					:	mA(a), mR(r), mG(g), mB(b)
					{}

	/// Getter
	tComp			R() const		{ return mR; }
	/// Setter
	void			R(tComp r)		{ mR = r; }
	/// Getter
	tComp			G() const		{ return mG; }
	/// Setter
	void			G(tComp g)		{ mG = g; }
	/// Getter
	tComp			B() const		{ return mB; }
	/// Setter
	void			B(tComp b)		{ mB = b; }
	/// Getter (Alpha currently unused in ATL)
	tComp			A() const		{ return mA; }
	/// Setter (Alpha currently unused in ATL)
	void			A(tComp a)		{ mA = a; }

	/// Return true if the color are equal
	bool			operator ==(const TAtlColor<componentType>& inOther) const
					{ return mA == inOther.mA && mR == inOther.mR && mG == inOther.mG && mB == inOther.mB; }

	/// Return true if the color are different
	bool			operator !=(const TAtlColor<componentType>& inOther) const
					{ return !operator ==(inOther); }

private:
   /// Alpha component (currently unused in ATL).
	tComp			mA;
   /// Color red component.
	tComp			mR;
   /// Color green component.
	tComp			mG;
   /// Color blue component.
	tComp			mB;
};

/// Color components in Atl accept values from 0 to 255.
typedef TAtlColor<unsigned char>	CAtlColor;

} // namespace  AvAtl

#endif
