/** \file
 * Header for the CAtlFeedback template
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef CAtlFeedback_h
#define CAtlFeedback_h

// We use this namespace for our library.
namespace  AvAtl {

class CAtlMgr;

/// Progression and warning support
/** \interface CAtlFeedback 
 * You can receive feedback on special situations in your warning function.
 * This will help you to debug your use of the ATL library.
 * For an example of use, see the atltest.cpp file.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
class CAtlFeedback
{
public:
	/// Inform your application of problems of any kind.
	/** Usually for programmers help (not for the application's user help).
	 * You do not have to overload this function.
	 * \param mgr the manager that reported the problem.
	 * \param warningmsg the warning message. */
	virtual void	warning(CAtlMgr* /* mgr */, tUtf8 /* warningmsg */) throw() {}

	/// Inform your application of the progression during reading/writing.
	/** So you can animate something or present a progress window with a cancel button.
	 * You do not have to overload this function.
	 * \param mgr the manager that is reading/writing.
	 * \param current the progression value.
	 *  if the value of current is between 0 and maximum, the progression is known.
	 *  if the value of current is -1, the progression is undetermined.
	 * \param maximum the progression's maximum value.
	 * \retval false if you want the operation to be cancelled.
	 * \retval true if you want operation to continue. */
	virtual bool	progress(CAtlMgr* /* mgr */, long /* current */, long /* maximum */) throw() { return true; }
};

} //end namespace

#endif
