/** \file
 * Header for the CAtlFileType class
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef CAtlFileType_h
#define CAtlFileType_h


// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


// We make our enums int, so you don't have to change your project settings.
#ifdef __MWERKS__
#pragma enumsalwaysint on
#endif


/// File type support for the open/save dialog box
/** \class CAtlFileType 
 * This class describes one file type that CAtlMgr can open.
 * You can use this information for your open/save dialog box.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
class CAtlFileType
{
public:
   /// Type of File
	enum
	{
		/// The format needs a binary stream.
      eBinary = 1,
      /// Mac must use the extension when saving   
		eMacUseExt = 2,
      /// Match doesn't care about the file type value.
		eMacAnyType = 4,
      /// Match doesn't care about the file creator value.
		eMacAnyCreator = 8			
	};

   /// Macintosh extension of the file (Ex. ".opt")
	const char*		mExtension;	
   /// Macintosh type.
	unsigned long	mType;
	/// Macintosh creator.		
	unsigned long	mCreator;
   /// Set of flags.
	int				mFlags;
	/// Name of this file type (Ex. "Art-lantis")		
	tUtf8				mName;			

						/// Constructor
                  CAtlFileType(const char* ext, unsigned long type, unsigned long creator, int flags, tUtf8 inName)
							:	mExtension(ext),
								mType(type),
								mCreator(creator),
								mFlags(flags),
								mName(inName)
							{}

                  /// Destructor
						~CAtlFileType() {}
};

#ifdef __MWERKS__
#pragma enumsalwaysint reset
#endif

} // namespace  AvAtl

#endif
