/** \file
 * Header for the CAtlPanoLink interface
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 30/05/2002
 */

#ifndef CAtlPanoLink_h
#define CAtlPanoLink_h


#ifndef CAtlVector_h
	#include "CAtlVector.h"
#endif
#ifndef CAtlVector2D_h
	#include "CAtlVector2D.h"
#endif
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


// We make our enums int, so you don't have to change your project settings.
#ifdef __MWERKS__
#pragma enumsalwaysint on
#endif


/// Information on link between camera.
/** \interface CAtlPanoLink 
 *	The information on a link
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 30/05/2002
 */
class CAtlPanoLink
{
public:
	enum { eNbHotspots = 5 };

	/// Get the index of first panorama.
	virtual int				getPanIndex1() const = 0;
	/// Set the index of first panorama.
	virtual void			setPanIndex1(int index) = 0;

	/// Get the index of second panorama.
	virtual int				getPanIndex2() const = 0;
	/// Set the index of second panorama.
	virtual void			setPanIndex2(int index) = 0;

	/// Get the camera direction in the first panorama.
	virtual CAtlVector		getDirection1() const = 0;
	/// Set the camera direction in the first panorama.
	virtual void			setDirection1(const CAtlVector& direction) = 0;

	/// Get the camera direction in the second panorama.
	virtual CAtlVector		getDirection2() const = 0;
	/// Set the camera direction in the second panorama.
	virtual void			setDirection2(const CAtlVector& direction) = 0;

	/// Get the zoom in the first panorama.
	virtual double			getZoom1() const = 0;
	/// Set the zoom in the first panorama.
	virtual void			setZoom1(double zoom) = 0;

	/// Get the zoom in the second panorama.
	virtual double			getZoom2() const = 0;
	/// Set the zoom in the second panorama.
	virtual void			setZoom2(double zoom) = 0;

	/// Get the pan in the first panorama.
	virtual double			getVerticalPan1() const = 0;
	/// Set the pan in the first panorama.
	virtual void			setVerticalPan1(double vplan) = 0;

	/// Get the pan in the second panorama.
	virtual double			getVerticalPan2() const = 0;
	/// Set the pan in the second panorama.
	virtual void			setVerticalPan2(double vplan) = 0;

	/// Get the hotspot in the first panorama.
	/** @param index index of the five 2d points [0..4] */
	virtual CAtlVector2D	getHotspot1(int index) const = 0;
	/// Set the hotspot in the first panorama.
	/** @param index index of the five 2d points [0..4] */
	virtual void			setHotspot1(int index, const CAtlVector2D& hotspot) = 0;

	/// Get the hotspot in the second panorama.
	/** @param index index of the five 2d points [0..4] */
	virtual CAtlVector2D	getHotspot2(int index) const = 0;
	/// Set the hotspot in the second panorama.
	/** @param index index of the five 2d points [0..4] */
	virtual void			setHotspot2(int index, const CAtlVector2D& hotspot) = 0;

// End of API 1

	/// Put an XML representation of the link inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef		putInXML(XMLNodeRef inFatherNode) const = 0;

	/// Initialize the link with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool			initWithXML(XMLNodeRef inFatherNode) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.*/
	virtual					~CAtlPanoLink() {}
};


#ifdef __MWERKS__
#pragma enumsalwaysint reset
#endif


} // namespace  AvAtl

#endif
