/** \file
 * Header for the CAtlPlace interface
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 30/05/2002
 */

#ifndef CAtlPlace_h
#define CAtlPlace_h


// We use this namespace for our library.
namespace  AvAtl {


/// This class deal with geographic position.
/**
 * \interface CAtlPlace
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
class CAtlPlace
{
public:
	/// Get the longitude in minutes
	virtual int					getLongitude() const = 0;
	/// Set the longitude in minutes
	/** In minutes. Value > 0 means East while value < 0 means West.
	  * Reminder : 1 degree = 60 minutes.
	  * Value must be -7200 and 7200. */
	virtual void				setLongitude(int inLongitude) = 0;

	/// Get the latitude in minutes
	virtual int					getLatitude() const = 0;
	/// Set the latitude in minutes
	/** In minutes. Value > 0 means East while value < 0 means West.
	  * Reminder : 1 degree = 60 minutes.
	  * Value must be -3600 and 3600. */
	virtual void				setLatitude(int inLatitude) = 0;

	/// Get the time zone in minutes
	virtual int					getTimeZone() const = 0;
	/// Set the time zone in minutes
	/** Greenwich time zone difference in minutes.
	  * Value must be -12 and 12. */
	virtual void				setTimeZone(int inTimezone) = 0;

	/// Get the location daylight saving time usage.
	virtual bool				getDaylightSavingFlag() const = 0;
	/// Set the location daylight saving time usage.
	virtual void				setDaylightSavingFlag(bool daylighsaving) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.*/
	virtual						~CAtlPlace() {}
};


} // namespace  AvAtl

#endif
