/** \file
 * Header for the CAtlPolygon interface
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef CAtlPolygon_h
#define CAtlPolygon_h


// Basic class.
#ifndef CAtlVertex_h
	#include "CAtlVertex.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// Description of a polygon.
/** \interface CAtlPolygon 
 *	Information on a polygon and its holes.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
class CAtlPolygon
{
public:
	/// List of points index.
	typedef TAtlObjectMgr<CAtlVertex>			VertexMgr;

	/// Hole inside a polygon.
	/** \interface CAtlHole 
	 *	Shape of the hole inside a polygon.
	 *
	 * \author Abvent R&D Copyright (c) 2002
	 * \author Richard Young
	 * \version 1.0
	 * \date 04/02/2002
	 */
	class CAtlHole
	{
	public:
		/// Manager of point indexes in this hole.
		virtual VertexMgr*				getVertexMgr() = 0;

		/// Manager of point indexes in this hole.
		virtual const VertexMgr*		getVertexMgr() const = 0;

	protected:
		/** You must not create or delete objects of this class.
		    This is the responsibility of the CAtlMgr class.*/
		virtual							~CAtlHole() {}
	};
	/// List of polygon's holes.
	typedef TAtlObjectMgr<CAtlHole>	HoleMgr;

	///	Get the smoothing of this polygon.
	/**   Currently, holed polygons are always unsmoothed.
	      Art-lantis changes this value if the associated property smooth parameter is changed. */
	virtual bool					getSmooth() const = 0;
	///	Set the smoothing of this polygon.
	/**   Currently, holed polygons are always unsmoothed.
	      Art-lantis changes this value if the associated property smooth parameter is changed. */
	virtual void					setSmooth(bool smoothed) = 0;

	/// Get the property associated with this polygon.
	virtual int						getPropertyIndex() const = 0;
   /// Set the property associated with this polygon.
	virtual void					setPropertyIndex(int index) = 0;

	/// Manager of point indexes in this polygon.
	virtual VertexMgr*				getVertexMgr() = 0;

	/// Manager of point indexes in this polygon.
	const VertexMgr*				getVertexMgr() const
										{ return ((CAtlPolygon*)this)->getVertexMgr(); }

	/// Manager of holes.
	virtual HoleMgr*				getHoleMgr() = 0;

	/// Manager of holes.
	const HoleMgr*					getHoleMgr() const
										{ return ((CAtlPolygon*)this)->getHoleMgr(); }

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.*/
	virtual							~CAtlPolygon() {}

};


} // namespace  AvAtl

#endif
