/** \file
 * Header for the CAtlVector class
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef CAtlVector_h
#define CAtlVector_h

#include <stdexcept>

namespace  AvAtl {


/// Description of the 3d vector.
/** \class CAtlVector
 * The class CAtlVector is a structure use to describe the 3d space vector.
 * \note Indexing will throw an exception if the index is invalid.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
class CAtlVector
{
public:	
	/// Constructor.
					CAtlVector()
						:	mX(0), mY(0), mZ(0)
						{}
	/// Constructor.
					CAtlVector(double x, double y, double z)
						:	mX(x), mY(y), mZ(z)
						{}

	/// Getter
	double		X() const	{ return mX; }
   /// Setter
	void			X(double x) { mX = x; }
   /// Getter
	double		Y() const	{ return mY; }
   /// Setter
	void			Y(double y) { mY = y; }
   /// Getter
	double		Z() const	{ return mZ; }
   /// Setter
	void			Z(double z) { mZ = z; }

	/// Return the point specified by the index.
	double		operator[](unsigned int i) const { TestIndex(i);  return (&mX)[i]; }

	/// Return the point specified by the index.
	double&		operator[](unsigned int i) { TestIndex(i);  return (&mX)[i]; }

private:
	/// Validate the index, throw if invalid
	static void	TestIndex(unsigned int i)
					{
						if (i > 2)
							throw std::out_of_range("CAtlVector::TestIndex");
					}

   /// Spacial X component.
	double		mX;
   /// Spacial Y component.
	double		mY;
   /// Spacial Z component.
	double		mZ;

};

}

#endif