/** \file
 * Header for the CAtlVertex class
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 1.0
 * \date 03/03/2003
 */

#ifndef CAtlVertex_h
#define CAtlVertex_h


namespace  AvAtl {


/// Information on a vertex.
/** \class CAtlVertex
 * The class CAtlVertex is a structure use to describe a vertex.
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 1.0
 * \date 03/03/2003
 */
class CAtlVertex
{
public:
	// Flags values
	enum {
		kFlagVisibleNoUV	= 0,
		kFlagEdgeInvisible	= 1,
		kFlagUseUVMapping	= 2
	};

	/// Constructor
					CAtlVertex()
					:	mIndex(0),
						mFlags(kFlagVisibleNoUV),
						mU(0),
						mV(0)
					{}

	/// Get the index of the point.
	int				getIndex() const { return mIndex; }

	/// Set the index of the point.
	void			setIndex(int inIndex) { mIndex = inIndex; }

	/// Get the visibility of the edge from this point to the next.
	bool			getVisible() const { return (mFlags & kFlagEdgeInvisible) == 0; }

	/// Set the visibility of the edge from this point to the next.
	void			setVisible(bool inVisible) { if (inVisible) mFlags &= ~kFlagEdgeInvisible; else mFlags |= kFlagEdgeInvisible; }

	/// Control the usage of uv mapping.
	bool			getUseUV() const { return (mFlags & kFlagUseUVMapping) != 0; }

	/// Control the usage of uv mapping.
	void			setUseUV(bool inUse) { if (inUse) mFlags |= kFlagUseUVMapping; else mFlags &= ~kFlagUseUVMapping; }

	/// Get the uv mapping value.
	void			getUV(float* outU, float* outV) const { *outU = mU; *outV = mV; }

	/// Set the uv mapping value.
	void			setUV(float inU, float inV) { mU = inU;  mV = inV; }

private:
	/// Index of the point
	int				mIndex;

	/// Flags of this vertex
	int				mFlags;

	/// U coordinate for UV mapping
	float			mU;

	/// V coordinate for UV mapping
	float			mV;
};


} // namespace  AvAtl

#endif
