/*!
	\file	IAtl3DPlant.h
	\creator Abvent R&D Copyright 2004
	\creator Guillaume Boulet-Gercourt
	\date 16/04/2004
	\brief Definition of IAtl3DPlant interface
*/
#ifndef		IAtl3DPlant_h
# define	IAtl3DPlant_h


#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef CAtlProperty_h
	#include "CAtlProperty.h"
#endif
#ifndef CAtlTime_h
	#include	"CAtlTime.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif


// We use this namespace for our library.
namespace AvAtl {

#ifdef __MWERKS__
#pragma enumsalwaysint on
#endif


// Forward declaration
class IAtlAtlObjectDefinition;


/*!
	\addtogroup Atl Objects
	\{
*/

/*!
	\interface	IAtl3DPlant
	\brief Interface of 3D plants

	This interface shows the possibles interactions with atl 3D plants.
	Those plants are the same behavior than the basics atl objects.
*/
class IAtl3DPlant
{
public:
	/*!
		\enum eSeePlantType
		\brief definition of plant type
	*/
	enum	ePlantType
	{
		kUndefined,
		kTree,
		kFlower,
		kBushes,
		kPottedPlants,
		kPalmTree,
		kCactus,
		kWaterPlants,
		kFern
	};
	/*!
		\enum eColor
		\brief definition of vbvisual color codes

		Those codes are defined by VbVisual
	*/
	enum	eColor
	{
		kNoColors = -1,
		kWhite,
		kRed,
		kOrange,
		kRose,
		kPurple,
		kLightBlue,
		kDarkBlue,
		kYellow,
		kBrown
	};
	/// Class that implement association of a time period, Color, OverloadId
	class IPlantSetUp
	{
	public:
		//! Return the start time (for consulting)
		virtual const CAtlTime&				getStartTime() const = 0;
		//! Return the start time (for editing)
		virtual CAtlTime&					getStartTime() = 0;
		//! Return the end time (for consulting)
		virtual const CAtlTime&				getEndTime() const = 0;
		//! Return the end time (for editing)
		virtual CAtlTime&					getEndTime() = 0;
		/// Return the associated color
		virtual eColor						getColor() const = 0;
		/// Set the associated color
		virtual void						setColor(eColor inColor) = 0;
		/// Return the overlaod id
		virtual tUUID						getId() const = 0;
		/// Set the overlaod id
		virtual void						setId(tUUID inId) = 0;
	protected:
		/** You must not create or delete objects of this class.
		    This is the responsibility of the CAtlMgr class. */
		virtual								~IPlantSetUp () {}
	};

	/// List of plant setup availiable
	typedef TAtlObjectMgr<class IPlantSetUp>	PlantSetupMgr;

	/// Type conversion
	virtual const IAtlAtlObjectDefinition*	asAtlObjectDefinition() const = 0;

	/// Type conversion
	virtual IAtlAtlObjectDefinition*		asAtlObjectDefinition() = 0;

	//! Get the type of a plant
	virtual ePlantType				getType() const = 0;
	//! Set the type of a plant (like 'flower', 'tree', ...)
	virtual void					setType(ePlantType inType) = 0;

	//! Return a non modifiable plant setup
	virtual const PlantSetupMgr*	getPlantSetupMgr() const = 0;
	//! Return a modifiable plant setup
	virtual PlantSetupMgr*			getPlantSetupMgr() = 0;
protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtl3DPlant () {}
private:
};

/*!
	\} // group Atl Objects
*/

#ifdef __MWERKS__
#pragma enumsalwaysint reset
#endif

}		// namespace AvAtl

#endif		// IAtl3DPlant_h
