/** \file
 * Header for the IAtlAnimation interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 12/02/2003
 */

#ifndef IAtlAnimation_h
#define IAtlAnimation_h


// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// List of animations
typedef TAtlObjectMgr<class IAtlAnimation>			AtlAnimationsMgr;

/// List of camera path
typedef TAtlObjectMgr<class IAtlCameraPath>			AtlCameraPathMgr;


/// Define a name
/** \interface IAtlAnimation 
 *	Group members refers to their groups by name
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAtlAnimation
{
public:
	/// Put an XML representation of the group inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the group with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Return the name.
	/** Do not delete this string. */
	virtual tUtf8					getName() const = 0;

	/// Set the name.
	/** \param inName is in unicode. */
	virtual void					setName(tUtf8 inName) = 0;

	/// Return the list of this camera path.
	/** For consulting. */
	virtual const AtlCameraPathMgr*	getCameraPathMgr() const = 0;
	/// Return the list of this camera path.
	/** For settings. */
	virtual AtlCameraPathMgr*		getCameraPathMgr() = 0;

	/// Return the current path of this animation.
	virtual int						getCurrentPath() const = 0;
	/// Set the current path of this animation.
	virtual void					setCurrentPath(int inCurrent) = 0;

	/// Return the options of the view.
	/** For consulting. */
	virtual const class IAtlViewOpt*	getViewOpt() const = 0;
	/// Return the options of the view.
	/** For settings. */
	virtual class IAtlViewOpt*			getViewOpt() = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlAnimation() {}
};


} // namespace  AvAtl

#endif
