/** \file
 * Header for the IAltAtlObject interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 12/02/2003
 */

#ifndef IAltAtlObject_h
#define IAltAtlObject_h


// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAltAtlObjectMgr_h
	#include "TAltAtlObjectMgr.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// List of atl objects
typedef TAltAtlObjectMgr<class IAltAtlObject>		AltAtlObjectMgr;

/// List of properties
typedef TAtlObjectMgr<class CAtlProperty>			AtlPropertyMgr;


/// Define a name
/** \interface IAltAtlObject 
 *	Group members refers to their groups by name
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAltAtlObject
{
public:
	/// Put an XML representation of the group inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the group with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Return the name of the AtlObject.
	/** Do not delete this string. */
	virtual tUtf8					getName() const = 0;

	/// Set the name of the AtlObject.
	virtual void					setName(tURL inUrl) = 0;

	/// Return the URL of the AtlObject.
	/** Do not delete this string. */
	virtual tUtf8					getURL() const = 0;

	/// Set the URL of the AtlObject.
	virtual void					setURL(tURL inUrl) = 0;

	/// Get the localy affected properties of the AtlObject.
	/** For consulting */
	virtual const AtlPropertyMgr	getPropertyMgr() const = 0;

	/// Get the localy affected properties of the AtlObject.
	/** For setting */
	virtual AtlPropertyMgr			getPropertyMgr() = 0;

	/// Get the transformation matrix of the AtlObject.
	/** For consulting */
	virtual const class IAtlMatrix	getMatrix() const = 0;

	/// Get the transformation matrix of the AtlObject.
	/** For setting */
	virtual class IAtlMatrix		getMatrix() = 0;

	enum { kReferenceMainFile = -1 };

	/// Get the reference objet.
	/** Return the index in the list of Object (-1 for the main atl object). */
	virtual int						getReferenceObjetIndex() const = 0;

	/// Set the reference objet.
	/** inIndex is the index in the list of Object  (-1 for the main atl object). */
	virtual void					setReferenceObjetIndex(int inIndex) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAltAtlObject() {}
};


} // namespace  AvAtl

#endif
