/** \file
 * Header for the IAtlAtlObjectInstance interface
 *
 * \author Abvent R&D Copyright (c) 2004
 * \author Richard Young
 * \version 1.0
 * \date 26/04/2004
 */

#ifndef IAtlAtlObjectInstance_h
#define IAtlAtlObjectInstance_h


// Basic class.
#ifndef CAtlProperty_h
	#include "CAtlProperty.h"
#endif
#ifndef	CAtlLight_h
	#include "CAtlLight.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


// Forward declaration
class IAtlObjectInstance;


/// List of properties
typedef TAtlObjectMgr<CAtlProperty>			AtlPropertyMgr;
typedef TAtlObjectMgr<CAtlLight>			AtlLightMgr;

/** \interface IAtlAtlObjectInstance 
 *	Class that represent object instance
 *
 * \author Abvent R&D Copyright (c) 2004
 * \author Richard Young
 * \version 1.0
 * \date 27/04/2004
 */
class IAtlAtlObjectInstance
{
public:
	/// Type conversion to IAtlObjectInstance
	virtual const IAtlObjectInstance*	asObjectInstance() const = 0;

	/// Type conversion to IAtlObjectInstance
	virtual IAtlObjectInstance*			asObjectInstance() = 0;

	/// Return the URL of the AtlObject.
	/** Do not delete this string. */
	virtual tURL						getURL() const = 0;

	/// Set the URL of the AtlObject.
	virtual void						setURL(tURL inUrl) = 0;

	/// Get the localy affected properties of the AtlObject.
	/** For consulting */
	virtual const AtlPropertyMgr*		getPropertyMgr() const = 0;

	/// Get the localy affected properties of the AtlObject.
	/** For setting */
	virtual AtlPropertyMgr*				getPropertyMgr() = 0;

	/// Get the current selected properties
	virtual tUUID						getCurrentOverload() const = 0;

	/// Set the current selected properties
	virtual void						setCurrentOverload(tUUID inOverload) = 0;

	/// Get the light manager of the instance
	virtual const AtlLightMgr*			getLightMgr() const = 0;
	/// Get the light manager of the instance
	virtual AtlLightMgr*				getLightMgr() = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual								~IAtlAtlObjectInstance() {}
};


} // namespace  AvAtl

#endif
