/*!
	\file IAtlBBObjectInstance.h
	\author Abvent R&D Copyright (c) 2004
	\author Guillaume Boulet-Gercourt
	\version 1.0
	\date 15/09/2004
	\brief Header for the IAtlBBObjectInstance interface
*/
#ifndef		IAtlBBObjectInstance_h
# define	IAtlBBObjectInstance_h

// Basic class.
#ifndef AtlTypes_h
	#include	"AvAtlTypes.h"
#endif
#ifndef	IAtlTexture_h
	#include "IAtlTexture.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef	IAtlString_h
	#include "IAtlString.h"
#endif

// We use this namespace for our library.
namespace AvAtl {


// Forward declaration
class IAtlObjectInstance;


/*!
	\addtogroup Atl Objects
	\{
*/


/*!
	\interface IAtlBBObjectInstance
	\author Abvent R&D Copyright (c) 2004
	\author Guillaume Boulet-Gercourt
	\version 1.0
	\date 15/09/2004
	\brief Interface of billboards references
*/
class IAtlBBObjectInstance
{
public:
	/// the kind of the billboard
	enum eBillboardKind
	{
		kFlat,
		kUniface,
		kMultiface
	};
	/// the render type of the billboard
	enum eRenderType
	{
		/// the billboard will be rendered normally
		kNormal,
		/// the billboard will be rendered with corrections of brightness and contrast
		kDisplay
	};
	/// Type conversion to IAtlObjectInstance
	virtual const IAtlObjectInstance*	asObjectInstance() const = 0;

	/// Type conversion to IAtlObjectInstance
	virtual IAtlObjectInstance*			asObjectInstance() = 0;

	/// Check if the billboard must be oriented with the camera
	virtual bool	getOrientWithCamera() const = 0;
	/// Set if the billboard must be oriented with the camera
	virtual void	setOrientWithCamera(bool inOrient) = 0;

	/// Check if the texture of the billboard is verticaly inverted
	virtual bool	getVerticalFlip() const = 0;
	/// Set if the texture of the billboard is verticaly inverted
	virtual void	setVerticalFlip(bool inFlip) = 0;

	/// Check if the texture of the billboard is horizontaly inverted
	virtual bool	getHorizontalFlip() const = 0;
	/// Set if the texture of the billboard is horizontaly inverted
	virtual void	setHorizontalFlip(bool inFlip) = 0;

	/// Get the render type of the billboard
	virtual eRenderType	getRenderType() const = 0;
	/// Set the render type of the billboard
	virtual void		setRenderType(eRenderType inType) = 0;

	/// Get the shininess of the billboard
	virtual double		getShininess() const = 0;
	/// Set the shininess of the billboard
	/** Value is from 0 to 1 */
	virtual void		setShininess(double inShininess) = 0;

	/// Get the roughtness of the billboard
	virtual double		getRoughness() const = 0;
	/// Set the roughtness of the billboard
	/** Value is from 0 to 1000 */
	virtual void		setRoughness(double inRoughness) = 0;

	/// Get the brightness of the billboard
	virtual double		getBrightness() const = 0;
	/// Set the brightness of the billboard
	/** Value is from -0.5 to 0.5 */
	virtual void		setBrightness(double inBrightness) = 0;

	/// Get the contrast of the billboard
	virtual double		getContrast() const = 0;
	/// Set the contrast of the billboard
	/** Value is from 0 to +inf */
	virtual void		setContrast(double inContrast) = 0;

	/// Get the kind of the billboard
	virtual eBillboardKind	getBBKind() const = 0;
	/// Set the kind of the billboard
	virtual void			setBBKind(eBillboardKind inKind) = 0;

	/// Set the original size of the billboard
	virtual double			getDefinitionSize() const = 0;
	/// Get the original size of the billboard
	virtual void			setDefinitionSize(double inSize) = 0;

	/// Get the original localised name of the billboard
	/** For consulting */
	virtual const IAtlString&	getDefinitionName() const = 0;

	/// Get the original localised name of the billboard
	/** For editing */
	virtual IAtlString&	getDefinitionName() = 0;

	/// Get the url of the billboard
	/** Do not delete this string. */
	virtual tURL		getURL() const = 0;
	/// Set the url of the billboard
	virtual void		setURL(tURL inURL) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlBBObjectInstance() {}
};

/*!
	\} // group Atl Objects
*/

}		// namespace AvAtl

#endif		// IAtlBBObjectInstance_h

