/** \file
 * Header for the IAtlCameraLight interface
 *
 * \author Abvent R&D Copyright (c) 2004
 * \author Richard Young
 * \version 1.0
 * \date 28/09/2004
 */

#ifndef IAtlCameraLight_h
#define IAtlCameraLight_h


// Basic class.
#ifndef CAtlColor_h
	#include "CAtlColor.h"
#endif
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif

// We use this namespace for our library.
namespace  AvAtl {


/// Define the color and power of the camera light 
/** \interface IAtlCameraLight 
 *
 * \author Abvent R&D Copyright (c) 2004
 * \author Richard Young
 * \version 1.0
 * \date 28/09/2004
 */
class IAtlCameraLight
{
public:
	/// Put an XML representation of the camera light inside the father node.
	/** \retval the new node of the camera light.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the camera light with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Control if the camera light is used.
	virtual bool					getFlag() const = 0;
	/// Control if the camera light is used.
	virtual void					setFlag(bool inActive) = 0;

	/// Control if the camera light is used to compensate radiosity.
	virtual bool					getRadiosityFlag() const = 0;
	/// Control if the camera light is used to compensate radiosity.
	virtual void					setRadiosityFlag(bool inFlag) = 0;

	/// Get the color of the camera light
	virtual const CAtlColor&		getColor() const = 0;
	/// Set the color of the camera light
	virtual void					setColor(const CAtlColor& inColor) = 0;

	/// Get the power of the camera light
	virtual double					getPower() const = 0;
	/// Get the power of the camera light
	virtual void					setPower(double inPower) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
									~IAtlCameraLight() {}
};


} // namespace  AvAtl

#endif
