/** \file
 * Header for the IAtlClippingBox interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlClippingBox_h
#define IAtlClippingBox_h


#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef CAtlVector_h
	#include "CAtlVector.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// Define the clipping box used by the working window.
/** \interface IAtlClippingBox 
 *	Define the clipping box and it's state
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 22/02/2003
 */
class IAtlClippingBox
{
public:
	/// Put an XML representation of the clipping box inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the clipping box with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(ConstXMLNodeRef inFatherNode) = 0;

	/// The minimum of the clipping box
	virtual const CAtlVector&		getMinimum() const = 0;
	/// The minimum of the clipping box
	virtual void					setMinimum(const CAtlVector& inMinimum) = 0;

	/// The maximum of the clipping box
	virtual const CAtlVector&		getMaximum() const = 0;
	/// The maximum of the clipping box
	virtual void					setMaximum(const CAtlVector& inMaximum) = 0;

	/// Control the visibility of the clipping box
	virtual bool					getVisibleFlag() const = 0;
	/// Control the visibility of the clipping box
	virtual void					setVisibleFlag(bool inVisible) = 0;

	/// Control the usage of the clipping box
	virtual bool					getActiveFlag() const = 0;
	/// Control the usage of the clipping box
	virtual void					setActiveFlag(bool inActive) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlClippingBox() {}
};


} // namespace  AvAtl

#endif
