/** \file
 * Header for the IAtlDepthOfField interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlDepthOfField_h
#define IAtlDepthOfField_h


#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef CAtlVector_h
	#include "CAtlVector.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


// We make our enums int, so you don't have to change your project settings.
#ifdef __MWERKS__
#pragma enumsalwaysint on
#endif


/// Specify a depth of field
/** \interface IAtlDeepOfField 
 *	Specify a depth of field
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 17/03/2003
 */
class IAtlDepthOfField
{
public:
	// Type of depth
	enum EDepthType
	{
	    eDepthFromPoint,
	    eDepthFromTarget,
	    eDepthFromInfinity,
	    eDepthFromDistance
	};

	/// Put an XML representation of the atmosphere inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the atmosphere with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Control if the depth of field is used
	virtual bool					getUsed() const = 0;
	/// Control if the depth of field is used
	virtual void					setUsed(bool inUsed) = 0;

	/// Get the type of depth of field
	virtual EDepthType				getDepthType() const = 0;
	/// Set the type of depth of field
	virtual void					setDepthType(EDepthType inType) = 0;

	/// Get the clearness point
	virtual const CAtlVector&		getClearnessPoint() const = 0;
	/// Set the clearness point
	virtual void					setClearnessPoint(const CAtlVector& inPoint) = 0;

	/// Get the distance of clearness in cm
	virtual double					getInvClearnessDist() const = 0;
	/// Set the distance of clearness in cm
	virtual void					setInvClearnessDist(double inInvDist) = 0;

	/// Get the size of clearness
	virtual double					getInvClearnessSize() const = 0;
	/// Set the size of clearness
	virtual void					setInvClearnessSize(double inInvSize) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlDepthOfField() {}
};


#ifdef __MWERKS__
#pragma enumsalwaysint reset
#endif


} // namespace  AvAtl

#endif
