/** \file
 * Header for the IAtlForeground interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlForeground_h
#define IAtlForeground_h


// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// Define the foreground image and it's placement
/** \interface IAtlForeground 
 *	Foreground is rendered in front of all.
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAtlForeground
{
public:
	/// Put an XML representation of the foreground inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the foreground with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(ConstXMLNodeRef inFatherNode) = 0;

	/// The URL of the file used as a picture.
	virtual tUtf8					getImageURL() const = 0;
	/// The URL of the file used as a picture.
	virtual void					setImageURL(tUtf8 inName) = 0;

	/// Get the position (x) of the foreground relative to the background
	virtual int						getXPosition() const = 0;
	/// Set the position (x) of the foreground relative to the background
	virtual void					setXPosition(int inXPos) = 0;

	/// Get the position (y) of the foreground relative to the background
	virtual int						getYPosition() const = 0;
	/// Set the position (y) of the foreground relative to the background
	virtual void					setYPosition(int inYPos) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlForeground() {}
};


} // namespace  AvAtl

#endif
