/** \file
 * Header for the IAtlImage interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlImage_h
#define IAtlImage_h


#ifndef CAtlColor_h
	#include "CAtlColor.h"
#endif
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// Interface for image
/** \interface IAtlImage 
 * This class is used for images
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAtlImage
{
public:
	typedef unsigned int	Pixel;		// ARGB on Mac, BGRA on Win
										// Note: These 2 formats are identical in integer register but are different in memory

	/// Use this method to destroy a readed image.
	/** Don't destroy other images, unless specified. */
	virtual void		destroy() = 0;

	/// Return information on this image
	/** 0, 0, NULL indicate no image. */
	virtual void		getImage(int* outWidth, int* outHeight, const Pixel** outPixels) const = 0;

	/// Set the image.
	/** Set to 0, 0, NULL to indicate no image */
	virtual void		setImage(int inWidth, int inHeight, const Pixel* inPixels) = 0;

	/// Get the id of this image
	virtual tUUID		getId() const = 0;

	/// Set the id of this image
	virtual void		setId(tUUID inID) = 0;

protected:
	/** To delete a readed image, use destroy method. */
						~IAtlImage() {}
};


} // namespace  AvAtl

#endif
