/** \file
 * Header for the IAtlLensFlare interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlLensFlare_h
#define IAtlLensFlare_h


// We use this namespace for our library.
namespace  AvAtl {


// We make our enums int, so you don't have to change your project settings.
#ifdef __MWERKS__
#pragma enumsalwaysint on
#endif


/// Specify a lens flare
/** \interface IAtlLensFlare 
 *	Specify a lens flare
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAtlLensFlare
{
public:
	/// Type of lens flare.
	typedef enum {
		eLFLensFlare1,
		eLFLensFlare2,
		eLFHalo1,
		eLFHalo2
	} ELensFlareType;

	/// Control if the lens flare is used.
	virtual bool					getFlag() const = 0;
	/// Control if the lens flare is used.
	virtual void					setFlag(bool inFlag) = 0;

	/// Return the type of lens flare.
	virtual ELensFlareType			getType() const = 0;
	/// Set the type of lens flare.
	virtual void					setType(ELensFlareType inType) = 0;

	/// Return the size of lens flare.
	virtual double					getSize() const = 0;
	/// Set the size of lens flare.
	virtual void					setSize(double inSize) = 0;

	/// Return the intensity of lens flare.
	virtual double					getIntensity() const = 0;
	/// Set the intensity of lens flare.
	virtual void					setIntensity(double inIntensity) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual						~IAtlLensFlare() {}
};


#ifdef __MWERKS__
#pragma enumsalwaysint reset
#endif


} // namespace  AvAtl

#endif
