/** \file
 * Header for the IAtlLightsGroup interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlLightsGroup_h
#define IAtlLightsGroup_h


// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// List of UUID.
typedef TAtlObjectMgr<class CAtlUUID>	AtlUUIDMgr;


/// List of lights groups.
typedef TAtlObjectMgr<class IAtlLightsGroup>			AtlLightsGroupMgr;


/// Define a name
/** \interface IAtlLightsGroup 
 *	Group members refers to their groups by name
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAtlLightsGroup
{
public:
	/// Put an XML representation of the group inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the group with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Get the group ID
	virtual	tUUID					getId() const = 0;

	/// Set the group ID
	virtual	void					setId(tUUID inUUID) = 0;

	/// Return the name.
	/** Do not delete this string. */
	virtual tUtf8					getName() const = 0;

	/// Set the name.
	/** \param inName is in unicode. */
	virtual void					setName(tUtf8 inName) = 0;

	/// Get user interfaces private value
	virtual int						getUIValue() const = 0;

	/// Set user interfaces private value
	virtual void					setUIValue(int inValue) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlLightsGroup() {}

};


} // namespace  AvAtl

#endif
