
/*!
	\file	IAtlObject.h
	\creator Abvent R&D Copyright 2004
	\creator Guillaume Boulet-Gercourt
	\date 16/04/2004
	\brief Definition of IAtlObject interface
*/
#ifndef		IAtlObject_h
# define	IAtlObject_h

#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif

#ifndef		CAtlProperty_h
	#include	"CAtlProperty.h"
#endif

#ifndef TObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif

namespace  AvAtl {

/*!
	\addtogroup Atl Objects
	\{
	\brief This module contains all atl objects definitions


*/

class		CAtlMgr;
/*!
	\interface	IAtlObject
	\brief Interface of atl objects

	This interface shows the interactions with an Atl object, that will be used within Alhena.
	This object contains the geometry and shaders definition.
	It must be used with the interface IAtlObjectRef.
*/
class		IAtlObject
{
public:

	//! Set the ID of the object
	virtual void							setID(tUtf8 inID) = 0;
	//! Get the ID of the object
	virtual const tUtf8						getID(void) const = 0;

	//! set the type of an object (like '3D Plant, 'Light', ...)
	virtual void							setType(tUtf8 inType) = 0;
	//! get the type of an object
	virtual const tUtf8						getType(void) const = 0;

	//! set the name of the object
	virtual void							setName(tUtf8 inName) = 0;
	//! get the name of the object
	virtual const tUtf8						getName(void) const = 0;
	//! get the atl manager associated with this object
	virtual CAtlMgr *						getAtlMgr() const = 0;
	//! set the atl manager associated with this object
	virtual void							setAtlMgr(CAtlMgr* inMgr) = 0;
protected:
	virtual ~IAtlObject() {}
private:
};

/*!
	\} // group Atl Objects
*/

}	// namespace AvAtl


#endif	// IAtlObject_h
