/*!
	\file	IAtlObjectRef.h
	\creator Abvent R&D Copyright 2004
	\creator Guillaume Boulet-Gercourt
	\date 16/04/2004
	\brief Definition of IAtlObjectRef interface
*/
#ifndef		IAtlObjectRef_h
# define	IAtlObjectRef_h

#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif

#ifndef	IAtlObject_h
	#include "IAtlObject.h"
#endif


#ifndef	CAtlVector_h
	#include "CAtlVector.h"
#endif


namespace AvAtl {

/*!
	\addtogroup Atl Objects
	\{
*/

/*!
	\interface IAtlObjectRef
	\brief interface of atl objects references

	This interface shows the interactions with a reference to an Atl object : associated with an IAtlObject, it
	describes the position, rotation, scale of the object. So there can be several references to the same object.
*/
class		IAtlObjectRef
{
public:
	//! Get the url of the referenced object
	virtual tURL					getURL(void) const = 0;
	//! Set the url of the referenced object
	virtual void					setURL(tURL inURL) = 0;

	//! get the referenced object ID
	virtual tUtf8					getObjectID(void) const = 0;
	//! set the referenced object ID
	virtual void					setObjectID(tUtf8 inID) = 0;

	//! get the translation vector (for the object placement)
	virtual const CAtlVector&		getTranslation(void) const = 0;
	//! set the translation vector
	virtual void					setTranslation(const CAtlVector& inVector) = 0;
	
	//! get the rotation vector
	virtual const CAtlVector&		getRotation(void) const = 0;
	//! set the rotation vector
	virtual void					setRotation(const CAtlVector& inVector) = 0;

	//! get scale vector
	virtual const CAtlVector&		getScale(void) const = 0;
	//! set scale vector
	virtual void					setScale(const CAtlVector& inVector) = 0;
protected:
	virtual ~IAtlObjectRef() {}
private:
};

/*!
	\} // group Atl Objects
*/

}	// namespace AvAtl


#endif
