/** \file
 * Header for the IAtlPanoNode interface
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 30/05/2002
 */

#ifndef IAtlPanoNode_h
#define IAtlPanoNode_h


#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef CAtlVector_h
	#include "CAtlVector.h"
#endif
#ifndef EAtlViewFlags_h
	#include "EAtlViewFlags.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// Information on panorama camera
/** \interface IAtlPanoNode 
 *	The information on a panorama
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 30/05/2002
 */
class IAtlPanoNode
{
public:
	/// Return the name of the panorama.
	/** Do not delete this string. */
	virtual tUtf8			getName() const = 0;

	/// Set the name of the panorama.
	virtual void			setName(tUtf8 inName) = 0;

	/// Get the position of this panorama.
	virtual CAtlVector		getPosition() const = 0;
	/// Set the position of this panorama.
	virtual void			setPosition(const CAtlVector& inPosition) = 0;

	/// Get the direction of the panorama. (Initial panoramic camera direction) 
	virtual CAtlVector		getDirection() const = 0;
	/// Set the direction of the panorama. (Initial panoramic camera direction) 
	virtual void			setDirection(const CAtlVector& inDirection) = 0;

	/// Get view flags of the panorama camera.
	virtual AtlViewFlags	getFlags() const = 0;
	/// Set view flags of the panorama camera.
	virtual void			setFlags(AtlViewFlags inFlags) = 0;

	/// Get the focal of the camera.
	virtual double			getFocal() const = 0;
	/// Set the focal of the camera.
	virtual void			setFocal(double inFocal) = 0;

	/// Get the zoom of the camera.
	virtual double			getZoom() const = 0;
	/// Set the zoom of the camera.
	virtual void			setZoom(double inZoom) = 0;

	/// Get the pan of the camera.
	virtual double			getVerticalPan() const = 0;
	/// Set the pan of the camera.
	virtual void			setVerticalPan(double inPan) = 0;

	/// Get the number of links.
	virtual int				getNbLinks() const = 0;
	/// Set the number of links.
	virtual void			setNbLinks(int inNbLinks) = 0;

// End of API 1

	/// Put an XML representation of the panorama inside the father node.
	/** \retval the new node of the panorama.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef		putInXML(XMLNodeRef inFatherNode) const = 0;

	/// Initialize the panorama with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool			initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Return the view info of this view.
	/** For consulting */
	virtual const class IAtlViewInfo*	getViewInfo() const = 0;
	/// Return the view info of this view.
	/** For setting */
	virtual class IAtlViewInfo*			getViewInfo() = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.*/
	virtual					~IAtlPanoNode() {}
};


} // namespace  AvAtl

#endif
