/** \file
 * Header for the IAtlPanorama interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlPanorama_h
#define IAtlPanorama_h


// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef IAtlPanoNode_h
	#include "IAtlPanoNode.h"
#endif
#ifndef CAtlPanoLink_h
	#include "CAtlPanoLink.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// List of panoramas
typedef TAtlObjectMgr<class IAtlPanorama>			AtlPanoramasMgr;

/// List of panorama nodes
typedef TAtlObjectMgr<class IAtlPanoNode>			AtlPanoNodeMgr;

/// List of panorama links
typedef TAtlObjectMgr<class CAtlPanoLink>			AtlPanoLinkMgr;


/// Define a name
/** \interface IAtlPanorama 
 *	Group members refers to their groups by name
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAtlPanorama
{
public:
	/// Put an XML representation of the group inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the group with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Return the name.
	/** Do not delete this string. */
	virtual tUtf8					getName() const = 0;

	/// Set the name.
	/** \param inName is in unicode. */
	virtual void					setName(tUtf8 inName) = 0;

	/// Return the nodes of this panorama.
	/** For consulting. */
	virtual const AtlPanoNodeMgr*	getNodeMgr() const = 0;
	/// Return the nodes of this panorama.
	/** For settings. */
	virtual AtlPanoNodeMgr*			getNodeMgr() = 0;

	/// Return the links of this panorama.
	/** For consulting. */
	virtual const AtlPanoLinkMgr*	getLinkMgr() const = 0;
	/// Return the links of this panorama.
	/** For settings. */
	virtual AtlPanoLinkMgr*			getLinkMgr() = 0;

	/// Return the current node of this panorama.
	virtual int						getCurrentNode() const = 0;
	/// Set the current node of this panorama.
	virtual void					setCurrentNode(int inCurrent) = 0;

	/// Return the options of the view.
	/** For consulting. */
	virtual const class IAtlViewOpt*	getViewOpt() const = 0;
	/// Return the options of the view.
	/** For settings. */
	virtual class IAtlViewOpt*			getViewOpt() = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlPanorama() {}
};


} // namespace  AvAtl

#endif
