/** \file
 * Header for the IAtlRendererInfo interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlRendererInfo_h
#define IAtlRendererInfo_h


// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


/// Specify an renderer and it's private options
/** \interface IAtlRendererInfo 
 *	Specify an renderer and it's private options
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAtlRendererInfo
{
public:
	/// Put an XML representation of the name inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the name with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(ConstXMLNodeRef inFatherNode) = 0;

	/// Return the name.
	/** Do not delete this string. */
	virtual tUtf8					getRendererName() const = 0;

	/// Set the name.
	/** \param inName is in unicode. */
	virtual void					setRendererName(tUtf8 inName) = 0;

	/// Return the render options.
	/** For consulting */
	virtual ConstXMLNodeRef			getRendererOpt() const = 0;
	/// Return the render options.
	/** For changing */
	virtual XMLNodeRef				getRendererOpt() = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlRendererInfo() {}
};


} // namespace  AvAtl

#endif
