/** \file
 * Header for the IAtlViewInfo interface
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */

#ifndef IAtlViewInfo_h
#define IAtlViewInfo_h


// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef CAtlColor_h
	#include "CAtlColor.h"
#endif

#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef IAtlLightsGroup_h
	#include "IAtlLightsGroup.h"
#endif

// We use this namespace for our library.
namespace  AvAtl {


/// List of names (some objects are linked by name)
typedef TAtlObjectMgr<class IAtlLightsGroup>	AtlLightsGroupMgr;


/// Define common informations on views
/** \interface IAtlViewInfo 
 *	Common informations on views
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 2.0
 * \date 06/02/2003
 */
class IAtlViewInfo
{
public:
	/// Get the id of the view info
	virtual tUUID							getId() const = 0;
	/// Set the id of the view info
	virtual void							setId(tUUID inID) = 0;

	/// Control if the coordinates must not be changed.
	/** This is for interface purpose. */
	virtual bool							getCoordinatesLockedFlag() const = 0;
	/// Control if the coordinates must not be changed.
	/** This is for interface purpose. */
	virtual void							setCoordinatesLockedFlag(bool inLocked) = 0;

	/// Get user interfaces private value
	virtual int								getUIValue() const = 0;

	/// Set user interfaces private value
	virtual void							setUIValue(int inValue) = 0;

	/// Return the background of the view.
	/** For consulting */
	virtual const class CAtlBackground*		getBackground() const = 0;

	/// Return the background of the view.
	/** For setting */
	virtual class CAtlBackground*			getBackground() = 0;

	/// Return the foreground of the view.
	/** For consulting */
	virtual const class IAtlForeground*		getForeground() const = 0;

	/// Return the foreground of the view.
	/** For setting */
	virtual class IAtlForeground*			getForeground() = 0;

	/// Return the list of names of the groups of lights activated by this camera
	/** For consulting */
	virtual const  AtlUUIDMgr*				getLightsGroups() const = 0;
	/// Return the list of names of the groups of lights activated by this camera
	/** For setting */
	virtual AtlUUIDMgr*						getLightsGroups() = 0;

	/// Return the name of the heliodon used.
	/** The string is empty if no heliodon used. */
	virtual tUtf8							getHeliodonName() const = 0;
	/// Set the name of the heliodon used.
	/** Put an empty string for no heliodon used */
	virtual void							setHeliodonName(tUtf8 inName = "") = 0;

	/// Return the camera light of the view.
	/** For consulting */
	virtual const class IAtlCameraLight*	getCameraLight() const = 0;
	/// Return the camera light of the view.
	/** For setting */
	virtual class IAtlCameraLight*			getCameraLight() = 0;

	/// Return the radiosity camera light of the view.
	/** For consulting */
	virtual const class IAtlCameraLight*	getRadiosityCameraLight() const = 0;
	/// Return the radiosity camera light of the view.
	/** For setting */
	virtual class IAtlCameraLight*			getRadiosityCameraLight() = 0;

	/// Return the atmosphere of the view.
	/** For consulting */
	virtual const class CAtlAtmosphere*		getAtmosphere() const = 0;
	/// Return the atmosphere of the view.
	/** For setting */
	virtual class CAtlAtmosphere*			getAtmosphere() = 0;

	/// Return the depth of field of the view.
	/** For consulting */
	virtual const class IAtlDepthOfField*	getDepthOfField() const = 0;
	/// Return the depth of field of the view.
	/** For setting */
	virtual class IAtlDepthOfField*			getDepthOfField() = 0;

	/// Return the renderer used for this view.
	/** For consulting */
	virtual const class IAtlRendererInfo*	getRendererInfo() const = 0;
	/// Return the renderer used for this view.
	/** For setting */
	virtual class IAtlRendererInfo*			getRendererInfo() = 0;

	/// Return the clipping box of this view
	/** For consulting */
	virtual const class IAtlClippingBox*	getClippingBox() const = 0;

	/// Return the clipping box of this view
	/** For setting */
	virtual class IAtlClippingBox*			getClippingBox() = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsability of the CAtlMgr class.*/
											~IAtlViewInfo() {}
};


} // namespace  AvAtl

#endif
