/** \file
 * Header for the TAtlObjectMgr template interface
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef TAtlObjectMgr_h
#define TAtlObjectMgr_h


// We use this namespace for our library.
namespace  AvAtl {


/// Template interface for objects list
/** \interface TAtlObjectMgr
 * This template interface is used to manage the list of objects.
 * All lists inside Atl are exposed with this interface.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
template<class T> class TAtlObjectMgr
{
public:
	/// Return the number of objects.
	virtual int						getNbObjects() const = 0;

	/// Return the specified object.
	/** You must not use operator delete on this object (use removeObject).
	  * \param index the object's index.
	  * \return the object's pointer.
	  * \retval NULL if ths index is invalid (generate a warning). */
	virtual T*						getAtlObject(int index = 0) const = 0;

	/// Create a new object and put it at the specified index.
	/** You must not use operator delete on this object (use removeObject).
	  * \param index the object's index (-1 to place the object at the end).
	  * \return the pointer of the new object.
	  * \retval NULL if this index is invalid (generate a warning). */
	virtual T*						newAtlObject(int index = -1) = 0;

	/// Delete the specified object.
	/** The memory used by the object will be freed.
	  * Do nothing if index is invalid (generate a warning).
	  * \param index the object's index (-1 to delete the last object). */
	virtual void					removeObject(int index = -1) = 0;

// End of API 1
	/// Move the object specified by inObjectIndex to the new index.
	/**	\param inObjectIndex the current object's index.
		\param inNewIndex the new object's index. */
	virtual void					moveObject(int inObjectIndex, int inNewIndex) = 0;

protected:
	/**   You must not create or delete objects of this class.
	      This is the responsibility of the CAtlMgr class.   */
	virtual							~TAtlObjectMgr() {}

};


} // namespace  AvAtl

#endif
